@@ -3,13 +3,42 @@
     package Acme::Mitey::Cards::Card;
     use strict;
     use warnings;
+    no warnings qw( once void );
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Acme::Mitey::Cards::Mite";
-    our $MITE_VERSION = "0.007003";
+    our $MITE_VERSION = "0.010002";
 
+    # Mite keywords
+    BEGIN {
+        my ( $SHIM, $CALLER ) =
+          ( "Acme::Mitey::Cards::Mite", "Acme::Mitey::Cards::Card" );
+        (
+            *after, *around, *before,        *extends, *field,
+            *has,   *param,  *signature_for, *with
+          )
+          = do {
+
+            package Acme::Mitey::Cards::Mite;
+            no warnings 'redefine';
+            (
+                sub { $SHIM->HANDLE_after( $CALLER, "class", @_ ) },
+                sub { $SHIM->HANDLE_around( $CALLER, "class", @_ ) },
+                sub { $SHIM->HANDLE_before( $CALLER, "class", @_ ) },
+                sub { },
+                sub { $SHIM->HANDLE_has( $CALLER, field => @_ ) },
+                sub { $SHIM->HANDLE_has( $CALLER, has   => @_ ) },
+                sub { $SHIM->HANDLE_has( $CALLER, param => @_ ) },
+                sub { $SHIM->HANDLE_signature_for( $CALLER, "class", @_ ) },
+                sub { $SHIM->HANDLE_with( $CALLER, @_ ) },
+            );
+          };
+    }
+
+    # Mite imports
     BEGIN {
         require Scalar::Util;
+        *STRICT  = \&Acme::Mitey::Cards::Mite::STRICT;
         *bare    = \&Acme::Mitey::Cards::Mite::bare;
         *blessed = \&Scalar::Util::blessed;
         *carp    = \&Acme::Mitey::Cards::Mite::carp;
@@ -24,85 +53,7 @@
         *true    = \&Acme::Mitey::Cards::Mite::true;
     }
 
-    sub new {
-        my $class = ref( $_[0] ) ? ref(shift) : shift;
-        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
-        my $self  = bless {}, $class;
-        my $args =
-            $meta->{HAS_BUILDARGS}
-          ? $class->BUILDARGS(@_)
-          : { ( @_ == 1 ) ? %{ $_[0] } : @_ };
-        my $no_build = delete $args->{__no_BUILD__};
-
-        # Attribute: deck
-        if ( exists $args->{"deck"} ) {
-            (
-                do {
-                    use Scalar::Util ();
-                    Scalar::Util::blessed( $args->{"deck"} )
-                      and $args->{"deck"}->isa(q[Acme::Mitey::Cards::Deck]);
-                }
-              )
-              or croak "Type check failed in constructor: %s should be %s",
-              "deck", "Deck";
-            $self->{"deck"} = $args->{"deck"};
-        }
-        require Scalar::Util && Scalar::Util::weaken( $self->{"deck"} )
-          if exists $self->{"deck"};
-
-        # Attribute: reverse
-        if ( exists $args->{"reverse"} ) {
-            do {
-
-                package Acme::Mitey::Cards::Mite;
-                defined( $args->{"reverse"} ) and do {
-                    ref( \$args->{"reverse"} ) eq 'SCALAR'
-                      or ref( \( my $val = $args->{"reverse"} ) ) eq 'SCALAR';
-                }
-              }
-              or croak "Type check failed in constructor: %s should be %s",
-              "reverse", "Str";
-            $self->{"reverse"} = $args->{"reverse"};
-        }
-
-        # Enforce strict constructor
-        my @unknown = grep not(/\A(?:deck|reverse)\z/), keys %{$args};
-        @unknown
-          and croak(
-            "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
-
-        # Call BUILD methods
-        $self->BUILDALL($args) if ( !$no_build and @{ $meta->{BUILD} || [] } );
-
-        return $self;
-    }
-
-    sub BUILDALL {
-        my $class = ref( $_[0] );
-        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
-        $_->(@_) for @{ $meta->{BUILD} || [] };
-    }
-
-    sub DESTROY {
-        my $self  = shift;
-        my $class = ref($self) || $self;
-        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
-        my $in_global_destruction =
-          defined ${^GLOBAL_PHASE}
-          ? ${^GLOBAL_PHASE} eq 'DESTRUCT'
-          : Devel::GlobalDestruction::in_global_destruction();
-        for my $demolisher ( @{ $meta->{DEMOLISH} || [] } ) {
-            my $e = do {
-                local ( $?, $@ );
-                eval { $demolisher->( $self, $in_global_destruction ) };
-                $@;
-            };
-            no warnings 'misc';    # avoid (in cleanup) warnings
-            die $e if $e;          # rethrow
-        }
-        return;
-    }
-
+    # Gather metadata for constructor and destructor
     sub __META__ {
         no strict 'refs';
         no warnings 'once';
@@ -123,22 +74,90 @@
         };
     }
 
-    sub DOES {
-        my ( $self, $role ) = @_;
-        our %DOES;
-        return $DOES{$role} if exists $DOES{$role};
-        return 1            if $role eq __PACKAGE__;
-        return $self->SUPER::DOES($role);
+    # Standard Moose/Moo-style constructor
+    sub new {
+        my $class = ref( $_[0] ) ? ref(shift) : shift;
+        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
+        my $self  = bless {}, $class;
+        my $args =
+            $meta->{HAS_BUILDARGS}
+          ? $class->BUILDARGS(@_)
+          : { ( @_ == 1 ) ? %{ $_[0] } : @_ };
+        my $no_build = delete $args->{__no_BUILD__};
+
+        # Attribute deck (type: Deck)
+        # has declaration, file lib/Acme/Mitey/Cards/Card.pm, line 9
+        if ( exists $args->{"deck"} ) {
+            blessed( $args->{"deck"} )
+              && $args->{"deck"}->isa("Acme::Mitey::Cards::Deck")
+              or croak "Type check failed in constructor: %s should be %s",
+              "deck", "Deck";
+            $self->{"deck"} = $args->{"deck"};
+        }
+        require Scalar::Util && Scalar::Util::weaken( $self->{"deck"} )
+          if ref $self->{"deck"};
+
+        # Attribute reverse (type: Str)
+        # has declaration, file lib/Acme/Mitey/Cards/Card.pm, line 19
+        if ( exists $args->{"reverse"} ) {
+            do {
+
+                package Acme::Mitey::Cards::Mite;
+                defined( $args->{"reverse"} ) and do {
+                    ref( \$args->{"reverse"} ) eq 'SCALAR'
+                      or ref( \( my $val = $args->{"reverse"} ) ) eq 'SCALAR';
+                }
+              }
+              or croak "Type check failed in constructor: %s should be %s",
+              "reverse", "Str";
+            $self->{"reverse"} = $args->{"reverse"};
+        }
+
+        # Call BUILD methods
+        $self->BUILDALL($args) if ( !$no_build and @{ $meta->{BUILD} || [] } );
+
+        # Unrecognized parameters
+        my @unknown = grep not(/\A(?:deck|reverse)\z/), keys %{$args};
+        @unknown
+          and croak(
+            "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
+
+        return $self;
     }
 
-    sub does {
-        shift->DOES(@_);
+    # Used by constructor to call BUILD methods
+    sub BUILDALL {
+        my $class = ref( $_[0] );
+        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
+        $_->(@_) for @{ $meta->{BUILD} || [] };
+    }
+
+    # Destructor should call DEMOLISH methods
+    sub DESTROY {
+        my $self  = shift;
+        my $class = ref($self) || $self;
+        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
+        my $in_global_destruction =
+          defined ${^GLOBAL_PHASE}
+          ? ${^GLOBAL_PHASE} eq 'DESTRUCT'
+          : Devel::GlobalDestruction::in_global_destruction();
+        for my $demolisher ( @{ $meta->{DEMOLISH} || [] } ) {
+            my $e = do {
+                local ( $?, $@ );
+                eval { $demolisher->( $self, $in_global_destruction ) };
+                $@;
+            };
+            no warnings 'misc';    # avoid (in cleanup) warnings
+            die $e if $e;          # rethrow
+        }
+        return;
     }
 
     my $__XS = !$ENV{MITE_PURE_PERL}
       && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
     # Accessors for deck
+    # has declaration, file lib/Acme/Mitey/Cards/Card.pm, line 9
     if ($__XS) {
         Class::XSAccessor->import(
             chained   => 1,
@@ -147,17 +166,16 @@
     }
     else {
         *deck = sub {
-            @_ > 1
-              ? croak("deck is a read-only attribute of @{[ref $_[0]]}")
-              : $_[0]{"deck"};
+            @_ == 1 or croak('Reader "deck" usage: $self->deck()');
+            $_[0]{"deck"};
         };
     }
 
     # Accessors for reverse
+    # has declaration, file lib/Acme/Mitey/Cards/Card.pm, line 19
     sub reverse {
-        @_ > 1
-          ? croak("reverse is a read-only attribute of @{[ref $_[0]]}")
-          : (
+        @_ == 1 or croak('Reader "reverse" usage: $self->reverse()');
+        (
             exists( $_[0]{"reverse"} ) ? $_[0]{"reverse"} : (
                 $_[0]{"reverse"} = do {
                     my $default_value = $_[0]->_build_reverse;
@@ -175,9 +193,24 @@
                     $default_value;
                 }
             )
-          );
+        );
     }
 
+    # See UNIVERSAL
+    sub DOES {
+        my ( $self, $role ) = @_;
+        our %DOES;
+        return $DOES{$role} if exists $DOES{$role};
+        return 1            if $role eq __PACKAGE__;
+        return $self->SUPER::DOES($role);
+    }
+
+    # Alias for Moose/Moo-compatibility
+    sub does {
+        shift->DOES(@_);
+    }
+
+    # Method signatures
     our %SIGNATURE_FOR;
 
     $SIGNATURE_FOR{"to_string"} = sub {
@@ -186,15 +219,13 @@
         my ( %tmp, $tmp, @head );
 
         @_ == 1
-          or croak(
-            "Wrong number of parameters in signature for %s: %s, got %d",
-            "to_string", "expected exactly 1 parameters",
-            scalar(@_)
-          );
+          or
+          croak( "Wrong number of parameters in signature for %s: got %d, %s",
+            "to_string", scalar(@_), "expected exactly 1 parameters" );
 
         @head = splice( @_, 0, 1 );
 
-        # Parameter $head[0] (type: Defined)
+        # Parameter invocant (type: Defined)
         ( defined( $head[0] ) )
           or croak(
             "Type check failed in signature for to_string: %s should be %s",
